Package: fiber
Type: Package
Title: S7 Data Structures for Diffusion MRI Tractography
Version: 0.1.2
Authors@R: c(
    person(
        given = "Aymeric",
        family = "Stamm",
        role = c("aut", "cre"),
        email = "aymeric.stamm@cnrs.fr",
        comment = c(ORCID = "0000-0002-8725-3654")
    ))
Description: Provides three S7 classes — streamline, bundle, and bundle_set —
    for representing diffusion MRI tractography data in R, together with a
    concise set of methods for computing shape descriptors (arc-length,
    curvature, torsion, sinuosity), the Hausdorff distance between streamlines,
    arc-length reparametrization of streamlines and bundles onto uniform grids,
    combination of streamlines or bundles into a single bundle, combination of
    bundles from multiple subjects or sessions into a bundle_set, and coercion
    to and from the dwiFiber S4 class of the 'dti' package. See Dell'Acqua, F.,
    Descoteaux, M. and Leemans, A. (2024) "Handbook of Diffusion MR Tractography"
    <doi:10.1016/C2018-0-02520-7> for more about the mathematical and computational
    underpinnings of diffusion MRI tractography.
License: MIT + file LICENSE
Encoding: UTF-8
URL: https://github.com/tractoverse/fiber,
        https://tractoverse.github.io/fiber/
BugReports: https://github.com/tractoverse/fiber/issues
Imports: cli, methods, S7
Config/roxygen2/version: 8.0.0
Config/roxygen2/markdown: TRUE
Suggests: dti, tinytest
Collate: 'bundle.R' 'streamline.R' 'coerce.R' 'cpp11.R'
        'fiber-package.R' 'parametrize.R' 'shape.R' 'utils.R' 'zzz.R'
LinkingTo: cpp11
NeedsCompilation: yes
Packaged: 2026-05-27 17:37:49 UTC; stamm-a
Author: Aymeric Stamm [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8725-3654>)
Maintainer: Aymeric Stamm <aymeric.stamm@cnrs.fr>
Repository: CRAN
Date/Publication: 2026-05-30 13:40:15 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-30 16:59:09 UTC; unix
Archs: fiber.so.dSYM
