# Generated by roxygen2: do not edit by hand

export(add_shape_descriptors)
export(as_bundle)
export(as_bundle_set)
export(as_dwifiber)
export(as_streamline)
export(bind_bundle_sets)
export(bind_bundles)
export(bundle)
export(bundle_set)
export(compute_hausdorff_distance)
export(get_curvature)
export(get_curvilinear_length)
export(get_euclidean_length)
export(get_sinuosity)
export(get_torsion)
export(is_bundle)
export(is_bundle_set)
export(is_streamline)
export(reparametrize)
export(streamline)
useDynLib(fiber, .registration = TRUE)
