# Generated by cpp11: do not edit by hand

hausdorff_distance_cpp <- function(mat_a, mat_b) {
  .Call(`_fiber_hausdorff_distance_cpp`, mat_a, mat_b)
}

pairwise_hausdorff_cpp <- function(mats) {
  .Call(`_fiber_pairwise_hausdorff_cpp`, mats)
}
