% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/streamline.R
\name{is_streamline}
\alias{is_streamline}
\title{Test whether an object is a streamline}
\usage{
is_streamline(x)
}
\arguments{
\item{x}{An object.}
}
\value{
\code{TRUE} if \code{x} is of class \link{streamline}, otherwise \code{FALSE}.
}
\description{
Test whether an object is a streamline
}
\examples{
pts <- matrix(runif(15), ncol = 3, dimnames = list(NULL, c("X", "Y", "Z")))
sl <- streamline(points = pts)
is_streamline(sl)     # TRUE
is_streamline(42)     # FALSE
}
