% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shape.R
\name{compute_hausdorff_distance-fiber-streamline-method}
\alias{compute_hausdorff_distance-fiber-streamline-method}
\alias{compute_hausdorff_distance,fiber::streamline-method}
\title{\code{\link[=compute_hausdorff_distance]{compute_hausdorff_distance()}} method for two \code{streamline} objects}
\arguments{
\item{x}{A \link{streamline} object.}

\item{y}{A \link{streamline} object.}
}
\value{
A non-negative numeric scalar equal to
\eqn{\max(d_H(x \to y),\, d_H(y \to x))}, where
\eqn{d_H(A \to B) = \max_{a \in A} \min_{b \in B} \|a - b\|_2} is the
directed Hausdorff distance. The core computation is performed in C++
via \code{hausdorff_distance_cpp()}.
}
\description{
\code{\link[=compute_hausdorff_distance]{compute_hausdorff_distance()}} method for two \code{streamline} objects
}
\examples{
pts1 <- matrix(runif(30), ncol = 3)
colnames(pts1) <- c("X", "Y", "Z")
pts2 <- matrix(runif(30), ncol = 3)
colnames(pts2) <- c("X", "Y", "Z")
sl1 <- streamline(points = pts1)
sl2 <- streamline(points = pts2)
compute_hausdorff_distance(sl1, sl2)
}
\seealso{
\code{\link[=compute_hausdorff_distance]{compute_hausdorff_distance()}}
}
