% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bundle.R
\name{is_bundle_set}
\alias{is_bundle_set}
\title{Test whether an object is a bundle_set}
\usage{
is_bundle_set(x)
}
\arguments{
\item{x}{An object.}
}
\value{
\code{TRUE} if \code{x} is of class \link{bundle_set}, otherwise \code{FALSE}.
}
\description{
Test whether an object is a bundle_set
}
\examples{
pts <- matrix(runif(15), ncol = 3, dimnames = list(NULL, c("X", "Y", "Z")))
b <- bundle(streamlines = list(streamline(points = pts)))
bs <- bundle_set(bundles = list("sub-01" = b))
is_bundle_set(bs)  # TRUE
is_bundle_set(b)   # FALSE
}
