% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/coerce.R
\name{as_bundle-fiber-streamline-method}
\alias{as_bundle-fiber-streamline-method}
\alias{as_bundle,fiber::streamline-method}
\title{\code{\link[=as_bundle]{as_bundle()}} method for \code{streamline} objects}
\arguments{
\item{x}{A \link{streamline} object.}

\item{...}{Additional arguments (currently unused).}
}
\value{
A \link{bundle} containing \code{x} as its sole streamline.
}
\description{
\code{\link[=as_bundle]{as_bundle()}} method for \code{streamline} objects
}
\seealso{
\code{\link[=as_bundle]{as_bundle()}}
}
