% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shape.R
\name{get_curvature}
\alias{get_curvature}
\title{Curvature of a streamline}
\usage{
get_curvature(x)
}
\arguments{
\item{x}{A \link{streamline} object.}
}
\value{
A non-negative numeric vector of length \code{x@n_points} giving the
curvature \eqn{\kappa(s)} at each sampled point along the streamline.
Higher values indicate sharper bending at that location.
}
\description{
\code{get_curvature()} is function that computes the curvature of a
\link{streamline} object. The curvature \eqn{\kappa(s)} at each point
along the arc-length abscissa is computed using cubic smoothing
splines (3 degrees of freedom per component).
}
\examples{
pts <- matrix(runif(30), ncol = 3)
colnames(pts) <- c("X", "Y", "Z")
sl <- streamline(points = pts)
get_curvature(sl)
}
