% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shape.R
\name{get_sinuosity}
\alias{get_sinuosity}
\title{Sinuosity of a streamline}
\usage{
get_sinuosity(x)
}
\arguments{
\item{x}{A \link{streamline} object.}
}
\value{
A numeric scalar \eqn{\ge 1}.
}
\description{
\code{get_sinuosity()} is a function that computes the ratio of curvilinear
length to Euclidean length for a \link{streamline} object, with a value of
1 indicating a perfectly straight streamline and larger values indicating
greater curviness.
}
\examples{
pts <- matrix(runif(30), ncol = 3)
colnames(pts) <- c("X", "Y", "Z")
sl <- streamline(points = pts)
get_sinuosity(sl)
}
