% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shape.R
\name{get_euclidean_length}
\alias{get_euclidean_length}
\title{Euclidean length of a streamline}
\usage{
get_euclidean_length(x)
}
\arguments{
\item{x}{A \link{streamline} object.}
}
\value{
A non-negative numeric scalar.
}
\description{
\code{get_euclidean_length()} is a function that computes the Euclidean
(straight-line) distance of a \link{streamline} object.
}
\examples{
pts <- matrix(runif(30), ncol = 3)
colnames(pts) <- c("X", "Y", "Z")
sl <- streamline(points = pts)
get_euclidean_length(sl)
}
